@@ -1,7 +1,7 @@
 ## Bayesian CRM - extending original code of J. Jack Lee and Nan Chen, Department of Biostatistics, the University of Texas M. D. Anderson Cancer Center
 ## Now using exact inference, rjags, R2WinBUGS or BRugs 
 
-### MJS 23/09/15
+### MJS 20/11/15
 
 if(getRversion() >= "2.15.1") globalVariables(c("N1","pow","d","alpha","p2","logit<-","log.alpha","inverse","patient","toxicity","est","target.tox","q2.5","q97.5","q50","q25","q75","ndose","tox.cutpoints","xmin","ymin","xmax","ymax","Loss","Outcome","traj","Statistic","..density..","Toxicity","weight","Method","..count..","rec","obs","count","n"))
 
@@ -52,13 +52,14 @@ if(getRversion() >= "2.15.1") globalVariables(c("N1","pow","d","alpha","p2","log
 #	plot	     --> Should dose response curve be plotted after each cohort is entered? Defaults to FALSE
 # 	file	     --> name of the file where the dose-response plots are stored, in a pdf format
 #   seed		--> (Optional) Initial seed value (integer).
+# quietly --> Suppress output 
 #	N --> Final sample size (Deprecated). To be replaced with stop in future versions
 #     tox         --> number of successes (toxicities) (Deprecated)
 #     notox       --> number of failed patients (no-toxicities) (Deprecated)
 # ----------------------------------------------------------------------
 bcrm<-function(stop=list(nmax=NULL,nmtd=NULL,precision=NULL,nmin=NULL),data=NULL,p.tox0=NULL,sdose=NULL,dose=NULL,ff,prior.alpha,cohort=3,target.tox,constrain=TRUE,sdose.calculate="mean",pointest="plugin",tox.cutpoints=NULL,loss=NULL,
 	start=NULL,simulate=FALSE,nsims=1,truep=NULL,threep3=FALSE,
-	method="exact",burnin.itr=2000,production.itr=2000,bugs.directory="c:/Program Files/WinBUGS14/",plot=FALSE,seed=NULL, file=NULL,N,tox,notox){
+	method="exact",burnin.itr=2000,production.itr=2000,bugs.directory="c:/Program Files/WinBUGS14/",plot=FALSE,seed=NULL, quietly=FALSE, file=NULL,N,tox,notox){
 
 	# Checks of argument inputs	
 	if(missing(N) & is.null(stop$nmax) & is.null(stop$nmtd) & is.null(stop$precision)) stop("At least one stopping rule must be provided using the stop argument")
@@ -273,7 +274,7 @@ bcrm<-function(stop=list(nmax=NULL,nmtd=NULL,precision=NULL,nmin=NULL),data=NULL
 			}
 			stopped<-stop.check(stop,ncurrent,ndose,new.tox,new.notox,simulate)
 		}
-		if(simulate){
+		if(simulate & !quietly){
 			cat(sim,"\n")
 		}
 	sim<-sim+1
@@ -1225,22 +1226,22 @@ plot.bcrm.sim<-function(x,trajectories=FALSE,file=NULL,threep3=FALSE,...){
 		exp<-rep(dose,apply(sapply(x,function(i){(i$tox+i$notox)}),1,sum))
 		if(!threep3){
 			df.exp<-data.frame(exp=factor(exp))
-			b<-ggplot()+geom_histogram(aes(x=exp,y=100*..count../sum(..count..)),data=df.exp)+xlab(dose.label)+ylab("Percent")+ggtitle("Experimentation")
+			b<-ggplot()+geom_bar(aes(x=exp,y=100*..count../sum(..count..)),data=df.exp)+xlab(dose.label)+ylab("Percent")+ggtitle("Experimentation")
 		} else {
 			exp.threep3<-rep(dose,10000*x[[1]]$threep3$exp)
 			df.exp.threep3<-data.frame(exp=factor(c(exp,exp.threep3)),Method=rep(c("CRM","3+3"),c(length(exp),length(exp.threep3))),weight=c(rep(1/length(exp),length(exp)),rep(1/length(exp.threep3),length(exp.threep3))))
-			b<-ggplot()+geom_histogram(aes(x=exp,y=100*..count..,weight=weight,fill=Method),data=df.exp.threep3,position="dodge")+xlab(dose.label)+ylab("Percent")+ggtitle("Experimentation")
+			b<-ggplot()+geom_bar(aes(x=exp,y=100*..count..,weight=weight,fill=Method),data=df.exp.threep3,position="dodge")+xlab(dose.label)+ylab("Percent")+ggtitle("Experimentation")
 		}
 
 		# recommendation
 		rec<-dose[sapply(x,function(i){i$ndose[[length(i$ndose)]]$ndose})]
 		if(!threep3){
 			df.rec<-data.frame(rec=factor(rec))
-			c<-ggplot()+geom_histogram(aes(x=rec,y=100*..count../sum(count)),data=df.rec)+xlab(dose.label)+ylab("Percent")+ggtitle("Recommendation")
+			c<-ggplot()+geom_bar(aes(x=rec,y=100*..count../sum(count)),data=df.rec)+xlab(dose.label)+ylab("Percent")+ggtitle("Recommendation")
 		} else {
 			rec.threep3<-dose[x[[1]]$threep3$mtd]
 			df.rec.threep3<-data.frame(rec=factor(c(rec,rec.threep3)),weight=c(rep(1/length(rec),length(rec)),x[[1]]$threep$prob[x[[1]]$threep3$mtd!=0]),Method=rep(c("CRM","3+3"),c(length(rec),length(rec.threep3))))
-			c<-ggplot()+geom_histogram(aes(x=rec,y=100*..count..,weight=weight,fill=Method),data=df.rec.threep3,position="dodge")+xlab(dose.label)+ylab("Percent")+ggtitle("Recommendation")
+			c<-ggplot()+geom_bar(aes(x=rec,y=100*..count..,weight=weight,fill=Method),data=df.rec.threep3,position="dodge")+xlab(dose.label)+ylab("Percent")+ggtitle("Recommendation")
 		}
 		
           # observed DLTs
@@ -1285,12 +1286,12 @@ plot.threep3<-function(x,file=NULL,...){
 	# experimentation
 	exp.threep3<-rep(dose,10000*x$exp)
 	df.exp.threep3<-data.frame(exp=as.factor(exp.threep3))
-	b<-ggplot()+geom_histogram(aes(x=exp,y=..count../100),data=df.exp.threep3)+xlab(dose.label)+ylab("Percent")+ggtitle("Experimentation")
+	b<-ggplot()+geom_bar(aes(x=exp,y=..count../100),data=df.exp.threep3)+xlab(dose.label)+ylab("Percent")+ggtitle("Experimentation")
 
 	# recommendation
 	rec.threep3<-dose[x$mtd]
 	df.rec.threep3<-data.frame(rec=factor(rec.threep3),weight=x$prob[x$mtd!=0])
-	c<-ggplot()+geom_histogram(aes(x=rec,y=100*..count..,weight=weight),data=df.rec.threep3)+xlab(dose.label)+ylab("Percent")+ggtitle("Recommendation")
+	c<-ggplot()+geom_bar(aes(x=rec,y=100*..count..,weight=weight),data=df.rec.threep3)+xlab(dose.label)+ylab("Percent")+ggtitle("Recommendation")
 
      # observed DLTs
 	obs.threep3<-100*x$dlt.no/x$ssize
@@ -1441,9 +1442,11 @@ print.bcrm.sim<-function(x,tox.cutpoints=NULL,trajectories=FALSE,threep3=FALSE,.
 			rownames(tab0)<-"Sample size"
 			colnames(tab0)<-c("Mean","Minimum","Maximum")
 		}
-		exp<-apply(sapply(x,function(i){(i$tox+i$notox)/sum(i$tox+i$notox)}),1,mean)
-		rec<-prop.table(table(factor(sapply(x,function(i){i$ndose[[length(i$ndose)]]$ndose}),levels=1:length(x[[1]]$tox))))
-		tab<-signif(rbind(exp,rec),3)
+		exp<-sapply(x,function(i){(i$tox+i$notox)/sum(i$tox+i$notox)})
+		exp.tab<-apply(exp,1,mean)
+		rec<-sapply(x,function(i){i$ndose[[length(i$ndose)]]$ndose})
+		rec.tab<-prop.table(table(factor(rec,levels=1:length(x[[1]]$tox))))
+		tab<-signif(rbind(exp.tab,rec.tab),3)
 		rownames(tab)<-c("Experimentation proportion","Recommendation proportion")
 		dose<-if(is.null(x[[1]]$dose)){1:length(x[[1]]$truep)} else {x[[1]]$dose}
 		colnames(tab)<-dose
@@ -1473,6 +1476,7 @@ print.bcrm.sim<-function(x,tox.cutpoints=NULL,trajectories=FALSE,threep3=FALSE,.
 			print.threep3(x[[1]]$threep3,tox.cutpoints=tox.cutpoints,dose=dose)
 		}
 	}
+  invisible(list(rec=rec,exp=exp))
 }
 
 #-----------------------------------------------------------------------
